#[non_exhaustive]pub struct UpdateManyModel {
pub namespace: Namespace,
pub filter: Document,
pub update: UpdateModifications,
pub array_filters: Option<Vec<Bson>>,
pub collation: Option<Document>,
pub hint: Option<Bson>,
pub upsert: Option<bool>,
}Expand description
Updates multiple documents.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.namespace: NamespaceThe namespace on which the update should be performed.
filter: DocumentThe filter to use. All documents matching this filter will be updated.
update: UpdateModificationsThe update to perform.
array_filters: Option<Vec<Bson>>A set of filters specifying to which array elements an update should apply.
collation: Option<Document>The collation to use.
hint: Option<Bson>The index to use. Specify either the index name as a string or the index key pattern. If specified, then the query system will only consider plans using the hinted index.
upsert: Option<bool>Whether a new document should be created if no document matches the filter.
Defaults to false.
Implementations
Sourceimpl UpdateManyModel
impl UpdateManyModel
Sourcepub fn builder() -> UpdateManyModelBuilder
pub fn builder() -> UpdateManyModelBuilder
Create a builder for building UpdateManyModel.
On the builder, call .namespace(...), .filter(...), .update(...), .array_filters(...)(optional), .collation(...)(optional), .hint(...)(optional), .upsert(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of UpdateManyModel.